@@ -15,6 +15,7 @@ import os
 import dataclasses
 import decimal
 from queue import Queue
+from jaaql.utilities.utils_no_project_imports import get_cookie_attrs, format_cookie, COOKIE_JAAQL_AUTH
 from jaaql.utilities.utils import time_delta_ms, Profiler
 from flask import Response, Flask, request, jsonify, current_app
 from flask.json.provider import DefaultJSONProvider
@@ -40,7 +41,7 @@ ARG__auth_token = "auth_token"
 ARG__auth_token_for_refresh = "auth_token_for_refresh"
 ARG__connection = "connection"
 ARG__is_the_anonymous_user = "is_the_anonymous_user"
-ARG__auth_cookie = "auth_cookie"
+ARG__remember_me = "remember_me"
 ARG__verification_hook = "verification_hook"
 ARG_START__connection = "connection__"
 ARG_START__jaaql_connection = "jaaql_" + ARG_START__connection
@@ -82,8 +83,6 @@ HEADER__allow_origin = "Access-Control-Allow-Origin"
 HEADER__allow_methods = "Access-Control-Allow-Methods"
 HEADER__real_ip = "X-Real-IP"
 
-ENV__allow_cors = "ALLOW_CORS"
-
 BOOL__allowed = {
     "True": True,
     "False": False,
@@ -128,13 +127,10 @@ class BaseJAAQLController:
     internal_sentinel = False
     base_url = None
 
-    allow_cors = False
-
     def __init__(self, model: JAAQLModel, is_prod: bool, base_url: str, do_profiling: bool = False):
         super().__init__()
         BaseJAAQLController.base_url = base_url
         self.app = Flask(__name__, instance_relative_config=True)
-        BaseJAAQLController.allow_cors = os.environ.get(ENV__allow_cors, str(False)).lower().strip() == "true"
         self.json_serializer = JAAQLJSONProvider(self.app)
         self.app.config[FLASK__json_sort_keys] = False
         self.app.config[FLASK__max_content_length] = 1024 * 1024 * 2  # 2 MB
@@ -384,12 +380,11 @@ class BaseJAAQLController:
         return combined_data
 
     @staticmethod
-    def _cors(resp):
-        if BaseJAAQLController.allow_cors:
+    def _cors(resp, use_cors: bool = False):
+        if use_cors:
             resp.headers.add(HEADER__allow_origin, CORS__WILDCARD)
             resp.headers.add(HEADER__allow_headers, CORS__WILDCARD)
             resp.headers.add(HEADER__allow_methods, CORS__WILDCARD)
-        return resp
 
     def log_safe_dump_recursive(self, data):
         if isinstance(data, list):
@@ -433,7 +428,7 @@ class BaseJAAQLController:
         """
         return json.dumps(self.log_safe_dump_recursive(data))
 
-    def cors_route(self, route: str, swagger_documentation: Union[list, SwaggerDocumentation]):
+    def publish_route(self, route: str, swagger_documentation: Union[list, SwaggerDocumentation], use_cors: bool = False):
         documentation_as_lists = swagger_documentation
         if not isinstance(documentation_as_lists, list):
             documentation_as_lists = [documentation_as_lists]
@@ -444,7 +439,7 @@ class BaseJAAQLController:
             for method in cur_documentation.methods:
                 methods.append(method.method)
 
-        if BaseJAAQLController.allow_cors:
+        if use_cors:
             methods.append(REST__OPTIONS)
             swagger_documentation = documentation_as_lists[0]
 
@@ -453,7 +448,7 @@ class BaseJAAQLController:
             def routed_function(view_func_local):
                 if not self.model.has_installed and not route.startswith('/internal'):
                     resp = Response("Still installing. Be patient", status=HTTPStatus.SERVICE_UNAVAILABLE)
-                    self._cors(resp)
+                    self._cors(resp, use_cors)
                     return resp
                 start_time = datetime.now()
                 request_id = uuid.uuid4()
@@ -462,6 +457,7 @@ class BaseJAAQLController:
                 resp_type = current_app.json.mimetype
                 jaaql_resp = JAAQLResponse()
                 jaaql_resp.response_type = resp_type
+                remember_me = False
 
                 if not BaseJAAQLController.is_options():
                     the_method = BaseJAAQLController.get_method(swagger_documentation)
@@ -483,7 +479,7 @@ class BaseJAAQLController:
                     security_key = request.headers.get(HEADER__security)
                     auth_cookie = request.cookies.get(COOKIE_JAAQL_AUTH)
                     if auth_cookie is not None:
-                        security_key = auth_cookie.split("=")[1].split(";")[0].strip()
+                        security_key = auth_cookie
 
                     if swagger_documentation.security:
                         bypass_super = request.headers.get(HEADER__security_bypass)
@@ -504,11 +500,11 @@ class BaseJAAQLController:
                                 verification_hook.put((True, None, None))
 
                         elif verification_hook:
-                            account_id, username, ip_id, is_public = self.model.verify_auth_token_threaded(security_key,
-                                                                                                           ip_addr, verification_hook)
+                            account_id, username, ip_id, is_public, remember_me = self.model.verify_auth_token_threaded(security_key,
+                                                                                                                        ip_addr, verification_hook)
                             self.perform_profile(request_id, "Verify JWT Threaded")
                         else:
-                            account_id, username, ip_id, is_public = self.model.verify_auth_token(security_key, ip_addr)
+                            account_id, username, ip_id, is_public, remember_me = self.model.verify_auth_token(security_key, ip_addr)
                             self.perform_profile(request_id, "Verify JWT")
 
                     supply_dict = {}
@@ -524,8 +520,8 @@ class BaseJAAQLController:
                                 raise Exception(ERR__method_required_account_id)
                             supply_dict[ARG__account_id] = account_id
 
-                        if ARG__auth_cookie in inspect.getfullargspec(view_func_local).args:
-                            supply_dict[ARG__auth_cookie] = auth_cookie
+                        if ARG__remember_me in inspect.getfullargspec(view_func_local).args:
+                            supply_dict[ARG__remember_me] = auth_cookie
 
                         if method.parallel_verification:
                             supply_dict[ARG__verification_hook] = verification_hook
@@ -582,10 +578,6 @@ class BaseJAAQLController:
 
                         self.perform_profile(request_id, "Perform work")
 
-                        if not swagger_documentation.security:
-                            account_id = jaaql_resp.account_id
-                            ip_id = jaaql_resp.ip_id
-
                         status = jaaql_resp.response_code
                         method_response = BaseJAAQLController.get_response(the_method, status)
                         do_allow_all = False
@@ -594,7 +586,6 @@ class BaseJAAQLController:
                                 do_allow_all = True
                         if not do_allow_all:
                             resp = BaseJAAQLController.validate_output(method_response, resp)
-                        ret_status = status
 
                         self.perform_profile(request_id, "Validate output")
                     except Exception as ex:
@@ -643,18 +634,14 @@ class BaseJAAQLController:
                     resp = Response(resp, mimetype=jaaql_resp.response_type, status=jaaql_resp.response_code)
 
                 if request.cookies.get(COOKIE_JAAQL_AUTH) is not None and COOKIE_JAAQL_AUTH not in jaaql_resp.cookies:
-                    auth_cookie = COOKIE_JAAQL_AUTH + "=" + request.cookies.get(COOKIE_JAAQL_AUTH)
-                    auth_cookie_fields = [field for field in auth_cookie.split(";") if not field.strip().startswith(COOKIE_ATTR_MAX_AGE)]
-
-                    if self.model.vigilant_sessions:
-                        auth_cookie_fields.append(COOKIE_ATTR_MAX_AGE + "=" + COOKIE_VAL_INACTIVITY_15_MINUTES)
-
-                    resp.headers.add("Set-Cookie", "; ".join(auth_cookie_fields))
+                    resp.headers.add("Set-Cookie", format_cookie(COOKIE_JAAQL_AUTH, request.cookies.get(COOKIE_JAAQL_AUTH),
+                                                                 get_cookie_attrs(self.model.vigilant_sessions, remember_me, self.model.is_container),
+                                                                 self.model.is_https))
 
                 for _, cookie in jaaql_resp.cookies.items():
                     resp.headers.add("Set-Cookie", cookie)
 
-                self._cors(resp)
+                self._cors(resp, use_cors)
 
                 self.perform_profile(request_id, "Jsonify")
 
